@@ -15,7 +15,7 @@ import requests_oauthlib  # type: ignore[import]
 
 
 class ContributterRanking:
-    """Class for create cnotributter ranking and tweets."""
+    """Create cnotributter ranking and tweets."""
 
     def __init__(
         self,
@@ -125,17 +125,22 @@ class ContributterRanking:
         return collections.Counter(rank_data).most_common(top)
 
     def tweet_top_n(self, data: list[tuple[str, int]]) -> Any:
-        contents = [f"✨{self.day_before_str} の Contribution Ranking✨"]
+        contents = [f"✨Contribution Ranking - {self.day_before_str}✨"]
+        tr = str.maketrans("1234567890", "１２３４５６７８９０")
         for idx, (name, num) in enumerate(data):
-            tr = str.maketrans("1234567890", "１２３４５６７８９０")
-            prefix = str(idx + 1).translate(tr) + " "
             if idx == 0:
                 prefix = "🥇"
             elif idx == 1:
                 prefix = "🥈"
             elif idx == 2:
                 prefix = "🥉"
-            contents.append(f"{prefix} {num} contributions: @{name}さん")
+            elif idx == 3:
+                prefix = "🏅"
+            elif idx == 4:
+                prefix = "🎖️"
+            else:
+                prefix = str(idx + 1).translate(tr) + " "
+            contents.append(f"{prefix} {num}🟩: @{name}")
         else:
             contents.append("#contributter_ranking")
         params = {"status": "\n".join(contents)}
